@@ -130,7 +130,7 @@ function(data=mydata, n.mcut=1, miss.zero=FALSE, max.lines=30,
           "to transform each variable into a factor with the Transform and\n",
           "factor functions. To see examples enter:  > ?Transform\n", 
           "Or, specify a value for n.cat, ",
-          "such as:  > global(n.cat=4)\n", sep="")
+          "such as:  > style(n.cat=4)\n", sep="")
       .dash(63)
       for (j in 1:n.var) if (is.numeric(data[,j]) && nu[j] <= n.cat.temp)
         cat(names(data)[j], "\n")
